@@ -70,6 +70,34 @@ introjs <- function(session,
   
 }
 
+#' Read a JS callback function into rintrojs
+#'
+#' Reads a JS callback function into rintrojs
+#'
+#' @param funname The name of the function you want to use. Options include:
+#' \describe{
+#'   \item{switchTabs}{This function is intended to be passed to IntroJs's
+#'   \href{https://introjs.com/docs/intro/api/#introjsonbeforechangeprovidedcallback}{onbeforechange method}. It will switch the currently active tab in your
+#'   Shiny app to be the one containing the next element in your tour (this
+#'   function is called by IntroJs right before it moves to the next element).
+#'   Try running \code{shiny::runApp(system.file("examples/switchTabs.R",
+#'   package = "rintrojs"))} to see an example.
+#'   }
+#' }
+#' @return A string containing the body of a callback function
+#' @export
+#' @examples
+#' \dontrun{
+#' introjs(session, events = list(onbeforechange = readCallback("switchTabs")))
+#' }
+readCallback <- function(funname = c("switchTabs")) {
+  funname <- match.arg(funname)
+  
+  switch(funname,
+         switchTabs = I("rintrojs.callback.switchTabs(targetElement)"))
+  
+}
+
 #' @rdname introjs
 #' @export
 
@@ -110,31 +138,36 @@ hintjs <- function(session,
 #' )
 #' }
 
-introjsUI <- function(includeOnly = FALSE, cdn = FALSE, version = "2.5.0") {
-  if (!missing(version) && !cdn) {
-    warning("version parameter is ignored when cdn = FALSE")
+introjsUI <-
+  function(includeOnly = FALSE,
+           cdn = FALSE,
+           version = "2.5.0") {
+    if (!missing(version) && !cdn) {
+      warning("version parameter is ignored when cdn = FALSE")
+    }
+    shiny::tags$head(shiny::singleton(
+      shiny::tagList(
+        shiny::includeScript(if (cdn) {
+          paste0("https://cdn.jsdelivr.net/intro.js/",
+                 version,
+                 "/intro.min.js")
+        } else {
+          system.file("javascript/introjs/intro.min.js", package = "rintrojs")
+        }),
+        shiny::includeCSS(if (cdn) {
+          paste0("https://cdn.jsdelivr.net/intro.js/",
+                 version,
+                 "/introjs.min.css")
+        } else {
+          system.file("javascript/introjs/introjs.min.css",
+                      package = "rintrojs")
+        }),
+        if (!includeOnly) {
+          shiny::includeScript(system.file("javascript/rintro.js", package = "rintrojs"))
+        }
+      )
+    ))
   }
-  shiny::tags$head(shiny::singleton(
-    shiny::tagList(
-      shiny::includeScript(if (cdn) {
-        paste0("https://cdn.jsdelivr.net/intro.js/",
-               version, "/intro.min.js")
-      } else {
-        system.file("javascript/introjs/intro.min.js", package = "rintrojs")
-      }),
-      shiny::includeCSS(if (cdn) {
-        paste0("https://cdn.jsdelivr.net/intro.js/",
-               version, "/introjs.min.css")
-      } else {
-        system.file("javascript/introjs/introjs.min.css",
-                    package = "rintrojs")
-      }),
-      if (!includeOnly) {
-        shiny::includeScript(system.file("javascript/rintro.js", package = "rintrojs"))
-      }
-    )
-  ))
-}
 
 #' Generate intro elements in UI
 #'
